==> custom_pages-v1.12.8.zip: custom_pages/messages/bg/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Добавяне</strong> на {templateName} артикул',
    '<strong>Custom</strong> Pages' => '<strong>Персонализирани</strong> страници',
    '<strong>Edit</strong> snippet' => '<strong>Редактиране</strong> на фрагмент',
    'Add' => 'Добави',
    'Add a file icon before the title' => 'Добавете икона на файл преди заглавието',
    'Adds plain HTML content to your site.' => 'Добавя просто HTML съдържание към вашия сайт.',
    'Advanced' => 'Разширено',
    'Allows the user to manage custom pages.' => 'Позволява на потребителя да управлява потребителски страници.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Позволява да се добавят страници (маркдаун, iframe или връзки) към навигацията в пространството',
    'Allows you to add content in MarkDown syntax.' => 'Позволява ви да добавяте съдържание в синтаксиса MarkDown.',
    'Alternate text' => 'Алтернативен текст',
    'Always make a backup of your view files outside of your production environment!' => 'Винаги правете резервно копие на вашите файлове за преглед извън вашата среда с истински трафик!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Празен разрешен избор на шаблон ще позволи всички шаблони на контейнери за този контейнер.',
    'Back' => 'Назад',
    'Back to dashboard' => 'Върни се в работното място',
    'Back to overview' => 'Назад към общ преглед',
    'Back to space' => 'Назад към раздела',
    'Can manage custom pages' => 'Може да управлява потребителски страници',
    'Category' => 'Категория',
    'Configuration' => 'Конфигурация',
    'Content' => 'Съдържание',
    'Create' => 'Създай',
    'Css Class' => 'CSS клас',
    'Custom' => 'Персонализиран',
    'Custom Pages' => 'Персонализирани страници',
    'Custom pages' => 'Персонализирани страници',
    'Dashboard' => 'Табло',
    'Default' => 'По подразбиране',
    'Default Content' => 'Съдържание по подразбиране',
    'Delete' => 'Изтрий',
    'Edit' => 'Редактиране',
    'Edit Page' => 'Редактирай страница',
    'Empty' => 'Празно',
    'File' => 'Файл',
    'General' => 'Общ',
    'Html' => 'HTML',
    'ID' => 'Идентификационен номер',
    'Icon' => 'Икона',
    'Iframe' => 'Iframe',
    'Insert' => 'Поставяне',
    'Invalid request data!' => 'Невалидни данни за заявка!',
    'Invalid template selection!' => 'Невалиден избор на шаблон!',
    'Invalid type selection' => 'Невалиден избор на тип',
    'Invalid view file selection!' => 'Невалиден избор на файл с изглед!',
    'Link' => 'Линк',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Навигация',
    'On this page you can configure general settings of your custom pages.' => 'На тази страница можете да конфигурирате общи настройки на вашите потребителски страници.',
    'Overview' => 'Общ преглед',
    'PHP' => 'PHP',
    'Page' => 'Страница',
    'Pages' => 'Страници',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Моля, изберете един от следните типове съдържание. Типът съдържание определя как вашето съдържание е вградено във вашия сайт.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Моля, имайте предвид, че страниците, базирани на PHP, са уязвими за проблеми със сигурността, особено при обработка на въведените от потребителя данни. За повече информация, моля, разгледайте <a href="{url}"> най-добрите практики за защита на Yii</a>.',
    'Public' => 'Публичен',
    'Reset' => 'Нулиране',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Изберете тази настройка само за видими текстови разклонения. Премахнете отметката от тази настройка, в случай че този елемент се използва например като стойност на атрибута HTML.',
    'Settings' => 'Настройки',
    'Show additional file information (size)' => 'Показване на допълнителна информация за файла (размер)',
    'Snippet' => 'Фрагмент',
    'Snippets' => 'Фрагменти',
    'Sort Order' => 'Сортирай ред',
    'Source' => 'Източник',
    'Space' => 'Раздел',
    'Space Members only' => 'Само членове на раздела',
    'Space Navigation' => 'Навигация на раздел',
    'Spaces' => 'Раздели',
    'Stream' => 'Поток',
    'Style' => 'Стил',
    'Style Class' => 'Клас на стил',
    'Submit' => 'Изпращане',
    'Target Url' => 'Целеви URL адрес',
    'Template' => 'Шаблон',
    'Template Layout' => 'Оформление на шаблона',
    'Templates' => 'Шаблони',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Шаблоните ви позволяват да дефинирате комбинируеми фрагменти на страници с вградена функционалност за редактиране.',
    'This container does not allow any further items!' => 'Този контейнер не позволява други елементи!',
    'Title' => 'Заглавие',
    'Top Navigation' => 'Топ Навигация',
    'Topics' => 'Теми',
    'Type' => 'Тип',
    'Upload image' => 'Качи изображение',
    'User Account Menu (Settings)' => 'Меню на потребителския акаунт (Настройки)',
    'Visibility' => 'Видимост',
    'Will embed the result of a given url as an iframe element.' => 'Ще вгради резултата от даден URL като iframe елемент.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Ще пренасочи заявките към даден (относителен или абсолютен) URL адрес.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'С PHP базирани страници можете да създавате персонализирани страници посредством файлове за преглед във вашата файлова система. Моля, проверете конфигурацията на модула за повече информация.',
    'Without adding to navigation (Direct link)' => 'Без добавяне към навигация (директна връзка)',
    'You are not allowed to delete default content!' => 'Нямате право да изтривате съдържанието по подразбиране!',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/bg/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Добавяне</strong> на {templateName} артикул',
    '<strong>Custom</strong> Pages' => '<strong>Персонализирани</strong> страници',
    '<strong>Edit</strong> snippet' => '<strong>Редактиране</strong> на фрагмент',
    'Add' => 'Добави',
    'Add a file icon before the title' => 'Добавете икона на файл преди заглавието',
    'Adds plain HTML content to your site.' => 'Добавя просто HTML съдържание към вашия сайт.',
    'Advanced' => 'Разширено',
    'Allows the user to manage custom pages.' => 'Позволява на потребителя да управлява потребителски страници.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Позволява да се добавят страници (маркдаун, iframe или връзки) към навигацията в пространството',
    'Allows you to add content in MarkDown syntax.' => 'Позволява ви да добавяте съдържание в синтаксиса MarkDown.',
    'Alternate text' => 'Алтернативен текст',
    'Always make a backup of your view files outside of your production environment!' => 'Винаги правете резервно копие на вашите файлове за преглед извън вашата среда с истински трафик!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Празен разрешен избор на шаблон ще позволи всички шаблони на контейнери за този контейнер.',
    'Back' => 'Назад',
    'Back to dashboard' => 'Върни се в работното място',
    'Back to overview' => 'Назад към общ преглед',
    'Back to space' => 'Назад към раздела',
    'Can manage custom pages' => 'Може да управлява потребителски страници',
    'Category' => 'Категория',
    'Configuration' => 'Конфигурация',
    'Content' => 'Съдържание',
    'Create' => 'Създай',
    'Css Class' => 'CSS клас',
    'Custom' => 'Персонализиран',
    'Custom Pages' => 'Персонализирани страници',
    'Custom pages' => 'Персонализирани страници',
    'Dashboard' => 'Табло',
    'Default' => 'По подразбиране',
    'Default Content' => 'Съдържание по подразбиране',
    'Delete' => 'Изтрий',
    'Edit' => 'Редактиране',
    'Edit Page' => 'Редактирай страница',
    'Empty' => 'Празно',
    'File' => 'Файл',
    'General' => 'Общ',
    'Html' => 'HTML',
    'ID' => 'Идентификационен номер',
    'Icon' => 'Икона',
    'Iframe' => 'Iframe',
    'Insert' => 'Поставяне',
    'Invalid request data!' => 'Невалидни данни за заявка!',
    'Invalid template selection!' => 'Невалиден избор на шаблон!',
    'Invalid type selection' => 'Невалиден избор на тип',
    'Invalid view file selection!' => 'Невалиден избор на файл с изглед!',
    'Link' => 'Линк',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Навигация',
    'On this page you can configure general settings of your custom pages.' => 'На тази страница можете да конфигурирате общи настройки на вашите потребителски страници.',
    'Overview' => 'Общ преглед',
    'PHP' => 'PHP',
    'Page' => 'Страница',
    'Pages' => 'Страници',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Моля, изберете един от следните типове съдържание. Типът съдържание определя как вашето съдържание е вградено във вашия сайт.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Моля, имайте предвид, че страниците, базирани на PHP, са уязвими за проблеми със сигурността, особено при обработка на въведените от потребителя данни. За повече информация, моля, разгледайте <a href="{url}"> най-добрите практики за защита на Yii</a>.',
    'Public' => 'Публичен',
    'Reset' => 'Нулиране',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Изберете тази настройка само за видими текстови разклонения. Премахнете отметката от тази настройка, в случай че този елемент се използва например като стойност на атрибута HTML.',
    'Settings' => 'Настройки',
    'Show additional file information (size)' => 'Показване на допълнителна информация за файла (размер)',
    'Snippet' => 'Фрагмент',
    'Snippets' => 'Фрагменти',
    'Sort Order' => 'Сортирай ред',
    'Source' => 'Източник',
    'Space' => 'Раздел',
    'Space Members only' => 'Само членове на раздела',
    'Space Navigation' => 'Навигация на раздел',
    'Spaces' => 'Раздели',
    'Stream' => 'Поток',
    'Style' => 'Стил',
    'Style Class' => 'Клас на стил',
    'Submit' => 'Изпращане',
    'Target Url' => 'Целеви URL адрес',
    'Template' => 'Шаблон',
    'Template Layout' => 'Оформление на шаблона',
    'Templates' => 'Шаблони',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Шаблоните ви позволяват да дефинирате комбинируеми фрагменти на страници с вградена функционалност за редактиране.',
    'This container does not allow any further items!' => 'Този контейнер не позволява други елементи!',
    'Title' => 'Заглавие',
    'Top Navigation' => 'Топ Навигация',
    'Topics' => 'Теми',
    'Type' => 'Тип',
    'Upload image' => 'Качи изображение',
    'User Account Menu (Settings)' => 'Меню на потребителския акаунт (Настройки)',
    'Visibility' => 'Видимост',
    'Will embed the result of a given url as an iframe element.' => 'Ще вгради резултата от даден URL като iframe елемент.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Ще пренасочи заявките към даден (относителен или абсолютен) URL адрес.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'С PHP базирани страници можете да създавате персонализирани страници посредством файлове за преглед във вашата файлова система. Моля, проверете конфигурацията на модула за повече информация.',
    'Without adding to navigation (Direct link)' => 'Без добавяне към навигация (директна връзка)',
    'You are not allowed to delete default content!' => 'Нямате право да изтривате съдържанието по подразбиране!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
